Module config

Module config 

Structs

CliOverrides
CLI overrides that can be applied on top of a loaded config.
CodegenConfig
ImportsConfig
InputConfig
NamingConfig
OutputConfig
RpcConfig
WatchConfig

Enums

FieldNaming

Constants

CONFIG_FILE_NAME

Functions

discover
Walk up from start looking for rpc.config.toml. Returns None if not found.
load
Read and parse a config file at the given path.
resolve
Resolve config: discover/load the file, then apply CLI overrides.