Module config
vercel_
rpc_
cli
0.1.4
Module config
Module Items
Structs
Enums
Constants
Functions
In crate vercel_
rpc_
cli
vercel_rpc_cli
Module
config
Structs

CliOverrides
CLI overrides that can be applied on top of a loaded config.
Codegen
Config
Imports
Config
Input
Config
Naming
Config
Output
Config
RpcConfig
Watch
Config
Enums

Field
Naming
Constants

CONFIG_
FILE_
NAME
Functions

discover
Walk up from
start
looking for
rpc.config.toml
. Returns
None
if not found.
load
Read and parse a config file at the given path.
resolve
Resolve config: discover/load the file, then apply CLI overrides.